@@ -5,6 +5,7 @@ getEdges <- function(graph){
 	labelx <- numeric(0)
 	labely <- numeric(0)
 	curveL <- logical(0)
+	weightStrL <- character(0)
 	for (node in nodes(graph)) {
 		edgeL <- edgeWeights(graph)[[node]]	
 		if (length(edgeL)!=0) {
@@ -12,6 +13,7 @@ getEdges <- function(graph){
 				# Label: Are these silent "tries" really tested? Or did I just forgot documentating it?
 				weight <- try(edgeData(graph, node, names(edgeL[i]), "weight"), silent = TRUE)
 				weight <- ifelse(edgeL[i]==0, NaN, edgeL[i])
+				weightStr <- getWeightStr(graph, node, names(edgeL[i]))
 				x <- try(unlist(edgeData(graph, node, names(edgeL[i]), "labelX")), silent = TRUE)
 				if (class(x)!="try-error") {
 					labelx <- c(labelx, x)
@@ -29,10 +31,11 @@ getEdges <- function(graph){
 				weightL <- c(weightL, weight)
 				curve <- node%in%unlist(edges(graph, names(edgeL[i])))
 				curveL <- c(curveL, curve)
+				weightStrL <- c(weightStrL, weightStr)
 			}
 		}
 	}
-	return(list(from=fromL, to=toL, weight=weightL, labelx=labelx, labely=labely, curve=curveL))
+	return(list(from=fromL, to=toL, weight=weightL, labelx=labelx, labely=labely, curve=curveL, weightStr=weightStrL))
 }
 
 arrangeNodes <- function(graph) {
@@ -61,13 +64,15 @@ stupidWorkAround <- function(graph) {
 	return(graph)
 }
 
-getAllQuadraticMatrices <- function(envir=globalenv()) {
+getAllQuadraticMatrices <- function(envir=globalenv(), n="all") {
 	objects <- ls(envir)
 	matrices <- c()
 	for (obj in objects) {
 		candidate <- get(obj, envir=envir)
 		if (is.matrix(candidate) && dim(candidate)[1] == dim(candidate)[2]) {
-			matrices <- c(matrices, obj)
+			if (n!="all" && dim(candidate)[1]==n) {
+				matrices <- c(matrices, obj)
+			}
 		}
 	}
 	if (length(matrices)==0) return("No quadratic matrices found.")
