@@ -84,6 +84,24 @@ public class Edge {
 		this.k2 = k2;
 	}
 	
+	public Edge(Node from, Node to, String wStr, VS vs, boolean curve) {
+		this(from, to, new EdgeWeight(wStr), vs, curve);
+	}
+
+	public Edge(Node from, Node to, String wStr, VS vs, int i, int j) {
+		this(from, to, new EdgeWeight(wStr), vs, i, j);	
+	}
+
+	public Edge(Node from, Node to, EdgeWeight ew, VS vs, int k1, int k2) {
+		this(from, to, 0d, vs, k1, k2);
+		this.ew = ew;
+	}
+
+	public Edge(Node from, Node to, EdgeWeight ew, VS vs, boolean curve) {
+		this(from, to, 0d, vs, curve);
+		this.ew = ew;
+	}
+
 	public int getBendLeft() {
 		int x1, x2, y1, y2;
 		x1 = from.getX() + Node.getRadius();
@@ -253,4 +271,8 @@ public class Edge {
 	public double getW(Hashtable<String, Double> ht) {
 		return ew.getWeight(ht);
 	}
+	
+	public EdgeWeight getEdgeWeight() {
+		return ew;
+	}
 }
